@@ -2,10 +2,10 @@ use pyo3::create_exception;
 use pyo3::exceptions::PyException;
 
 mod cell;
-mod reader;
 mod sheet;
+mod workbook;
 pub use cell::CellValue;
-pub use reader::CalamineReader;
 pub use sheet::CalamineSheet;
+pub use workbook::CalamineWorkbook;
 
 create_exception!(python_calamine, CalamineError, PyException);
